[pypy-commit] pypy app_main-refactor: fix py.py now that pypy_initial_path has gone

antocuni noreply at buildbot.pypy.org
Fri Jun 8 17:33:17 CEST 2012


Author: Antonio Cuni <anto.cuni at gmail.com>
Branch: app_main-refactor
Changeset: r55511:5e7431c1a880
Date: 2012-06-08 17:06 +0200
http://bitbucket.org/pypy/pypy/changeset/5e7431c1a880/

Log:	fix py.py now that pypy_initial_path has gone

diff --git a/pypy/bin/py.py b/pypy/bin/py.py
--- a/pypy/bin/py.py
+++ b/pypy/bin/py.py
@@ -89,12 +89,12 @@
     space.setitem(space.sys.w_dict, space.wrap('executable'),
                   space.wrap(argv[0]))
 
     # call pypy_initial_path: the side-effect is that it sets sys.prefix and
     # sys.exec_prefix
-    srcdir = os.path.dirname(os.path.dirname(pypy.__file__))
-    space.appexec([space.wrap(srcdir)], """(srcdir):
+    executable = argv[0]
+    space.appexec([space.wrap(executable)], """(executable):
         import sys
-        sys.pypy_initial_path(srcdir)
+        sys.pypy_find_stdlib(executable)
     """)
 
     # set warning control options (if any)
@@ -89,12 +89,12 @@
                   space.wrap(argv[0]))
 
-    # call pypy_initial_path: the side-effect is that it sets sys.prefix and
+    # call pypy_find_stdlib: the side-effect is that it sets sys.prefix and
     # sys.exec_prefix


More information about the pypy-commit mailing list